@@ -1,15 +1,15 @@
 package WordList::SU::LTIS;
 
 our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("num_words",4167,"avg_word_len",7.44324454043676,"longest_word_len",19,"num_words_contains_nonword_chars",573,"num_words_contains_whitespace",0,"num_words_contains_unicode",572,"shortest_word_len",2); # STATS
+our %STATS = ("num_words_contains_nonword_chars",573,"num_words",4167,"shortest_word_len",2,"longest_word_len",19,"num_words_contains_unicode",572,"avg_word_len",7.44324454043676,"num_words_contains_whitespace",0); # STATS
 
 1;
-# ABSTRACT: Sundanese words Loka Tarjamah Otomatis Indonesia-Sunda
+# ABSTRACT: Sundanese words from Loka Tarjamah Otomatis Indonesia-Sunda
 
 
 
@@ -20,11 +20,11 @@ our %STATS = ("num_words",4167,"avg_word_len",7.44324454043676,"longest_word_len
 
 =head1 NAME
 
-WordList::SU::LTIS - Sundanese words Loka Tarjamah Otomatis Indonesia-Sunda
+WordList::SU::LTIS - Sundanese words from Loka Tarjamah Otomatis Indonesia-Sunda
 
 =head1 VERSION
 
-This document describes version 0.02 of WordList::SU::LTIS (from Perl distribution WordList-SU-LTIS), released on 2016-01-13.
+This document describes version 0.03 of WordList::SU::LTIS (from Perl distribution WordList-SU-LTIS), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
